URL_DOSIS_ACUMULADOS = {
    'primera': 'https://sisa.msal.gov.ar/datos/descargas/covid-19/files/covid_1raDosis_acumulado.csv',
    'segunda': 'https://sisa.msal.gov.ar/datos/descargas/covid-19/files/covid_2daDosis_acumulado.csv',
    'total': 'https://sisa.msal.gov.ar/datos/descargas/covid-19/files/covid_total_acumulado.csv'
}

URL_DOSIS_DIARIAS = {
    'primera': 'https://sisa.msal.gov.ar/datos/descargas/covid-19/files/covid_1raDosis_diario.csv',
    'segunda': 'https://sisa.msal.gov.ar/datos/descargas/covid-19/files/covid_2daDosis_diario.csv',
    'total': 'https://sisa.msal.gov.ar/datos/descargas/covid-19/files/covid_total_diario.csv'
}